What is PyMedPhys? — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# What is PyMedPhys?

A community effort to develop an open standard library for Medical Physics in Python. We build high quality, transparent software together via peer review and open source distribution. Open code is better science.

# What is PyMedPhys?

PyMedPhys is an open-source Medical Physics python library built by an open community that values and prioritises code sharing, review, improvement, and learning from each other. It is inspired by the collaborative work of our physics peers in astronomy and the Astropy Project. PyMedPhys is available on PyPI and GitHub. For more information, please read the Statement of Need.

## Beta level of development

PyMedPhys is currently within the `beta` stage of its life-cycle. It will stay in this stage until the version number leaves `0.x.x` and enters `1.x.x`. While PyMedPhys is in `beta` stage, no API is guaranteed to be stable from one release to the next. In fact, it is very likely that the entire API will change multiple times before a `1.0.0` release. In practice, this means that upgrading `pymedphys` to a new version will possibly break any code that was using the old version of pymedphys. We try to be abreast of this by providing details of any breaking changes from one release to the next within the Release Notes.

## Community

PyMedPhys has a Discourse community to both help you find your feet using PyMedPhys and to facilitate collaboration and general discussion. Please reach out over there and we’d love to get to know you!

# Documentation

PyMedPhys can be installed with:

    pip install pymedphys[user]

Further user installation instructions can be found in the Quick Start Guide.

The PyMedPhys documentation contains two overarching guides:

1. The Users Guide: where you can find instructions to get started with the library and the CLI, in-depth how-to guides (examples for users) on PyMedPhys’ various tools, some background information on individual PyMedPhys projects as well as the Technical Reference.

2. The Contributors Guide: for those who wish to make new contributions to the PyMedPhys library, CLI or app. Here you’ll find detailed workstation setup guides to enable contributions, important repository information, and some tips & tricks to overcome common issues.

# Development

The PyMedPhys project is managed using Poetry.

After cloning the repository, install the PyMedPhys dependencies and set up pre-commit by running:

    poetry install -E all
    poetry run pre-commit install

Run automated tests with:

    poetry run pymedphys dev tests

# Our Team

PyMedPhys is what it is today due to its maintainers and contributors, both past and present. Here is our team.

## Maintainers

- Simon Biggs

    - Radiotherapy AI, Australia

- Stuart Swerdloff

    - ELEKTA Pty Ltd: New Zealand

- Matthew Jennings

    - Royal Adelaide Hospital, Australia

- Phillip Chlap

    - University of New South Wales, Australia

    - Ingham Institute, Australia

## Active contributors

- Derek Lane

    - ELEKTA AB, Houston TX

- Jake Rembish

    - UT Health San Antonio, USA

- Nicola Lambri

    - IRCCS Humanitas Research Hospital, Italy

    - Humanitas University, Italy

- Cody Crewson

    - Saskatchewan Cancer Agency, Canada

- Fada Guan

    - Yale University School of Medicine, USA

## Past contributors

- Matthew Cooper

- Pedro Martinez

- Rafael Ayala

- Matthew Sobolewski

- Paul King

- Jacob McAloney